/*
 * This file is a part of the Yandex Advertising Network
 *
 * Version for Flutter (C) 2023 YANDEX
 *
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at https://legal.yandex.com/partner_ch/
 */

import Flutter
import YandexMobileAds

final class AppOpenAdCommandProvider: CommandProvider {
    
    var commands: [Command] {
        [
            .command(.appOpenAd(.show), showAppOpenAd),
            .command(.appOpenAd(.destroy), destroyAppOpenAd),
        ]
    }
    
    private let onDestroy: () -> Void
    private let ad: YMAAppOpenAd
    private var idCount = 0
    
    let name = "appOpenAd"
    
    init(ad: YMAAppOpenAd, onDestroy: @escaping () -> Void) {
        self.ad = ad
        self.onDestroy = onDestroy
    }
    
    private func showAppOpenAd(args: Any?, result: MethodCallResult) {
        guard let controller = Self.controller else {
            return result.error(.noViewController)
        }
        ad.show(from: controller)
        result.success()
    }
    
    private func destroyAppOpenAd(args: Any?, result: MethodCallResult) {
        onDestroy()
        result.success()
    }
}
